# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2017-11-01 15:58
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('wagtail_personalisation', '0013_add_dynamic_static_to_segment'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='segment',
            name='sessions',
        ),
        migrations.AddField(
            model_name='segment',
            name='static_users',
            field=models.ManyToManyField(to=settings.AUTH_USER_MODEL),
        ),
    ]
