# Generated by Django 2.0.7 on 2018-07-04 15:26

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_personalisation', '0020_rules_delete_relatedqueryname'),
    ]

    operations = [
        migrations.AlterField(
            model_name='personalisablepagemetadata',
            name='segment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.PROTECT, related_name='page_metadata', to='wagtail_personalisation.Segment'),
        ),
    ]
