# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2017-05-31 04:28
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_personalisation', '0008_devicerule'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='personalisablepage',
            name='canonical_page',
        ),
        migrations.RemoveField(
            model_name='personalisablepage',
            name='page_ptr',
        ),
        migrations.RemoveField(
            model_name='personalisablepage',
            name='segment',
        ),
        migrations.DeleteModel(
            name='PersonalisablePage',
        ),
    ]
