# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2017-06-01 11:48
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_personalisation', '0011_personalisablepagemetadata'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='personalisablepagemetadata',
            name='is_segmented',
        ),
    ]
