# Generated by Django 2.0.5 on 2018-07-19 09:57

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_personalisation', '0022_personalisablepagemetadata_canonical_protect'),
    ]

    operations = [
        migrations.AlterField(
            model_name='personalisablepagemetadata',
            name='variant',
            field=models.OneToOneField(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='_personalisable_page_metadata', to='wagtailcore.Page'),
        ),
    ]
