{% extends "modeladmin/index.html" %}
{% load i18n l10n staticfiles modeladmin_tags %}

{% block titletag %}{{ view.get_meta_title }}{% endblock %}

{% block css %}
    {{ block.super }}
    {{ view.media.css }}
{% endblock %}

{% block extra_js %}
    {{ view.media.js }}
{% endblock %}

{% block header %}
    <header class="nice-padding hasform">
        <div class="row">
            <div class="left">
                <div class="col">
                    {% block h1 %}<h1 {% if view.header_icon %}class="icon icon-{{ view.header_icon }}"{% endif %}>{{ view.get_page_title }}<span></span></h1>{% endblock %}
                </div>
                {% block search %}{% search_form %}{% endblock %}
            </div>
            {% block header_extra %}
                {% if user_can_create %}
                    <div class="right">
                        <div class="addbutton">
                            <a href="{% url 'segment:toggle_segment_view' %}" class="button" title="{% trans "Switch view" %}">Switch {% block toggle_view %}{% endblock%}view</a>
                            {% include 'modeladmin/includes/button.html' with button=view.button_helper.add_button %}
                            </div>
                        </div>
                    {% endif %}
            {% endblock %}
        </div>
    </header>
{% endblock %}
