# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-12-22 13:23
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_personalisation', '0005_userisloggedinrule'),
    ]

    operations = [
        migrations.AddField(
            model_name='segment',
            name='match_any',
            field=models.BooleanField(default=False, help_text='Should the segment match all the rules or just one of them?'),
        ),
    ]
